@@ -43,7 +43,7 @@ DEFAULT_BATCH_TIMEOUT = timedelta(seconds=0.05)
 
 
 class client(Stream):
-    """A hop-scotch client configured for LVAlert
+    """A hop-scotch client configured for igwn_alerts from GraceDB
 
     Parameters
     ----------
@@ -71,7 +71,7 @@ class client(Stream):
 
     .. code-block:: python
 
-        alert_client = client(group='lvalert-dev')
+        alert_client = client(group='gracedb-test')
         topics = alter_client.get_topics()
 
     Here is an example for running a listener.
@@ -83,7 +83,7 @@ class client(Stream):
                 alert = json.loads(payload)
                 ...
 
-        client = IGWNAlertClient(group='lvalert-dev')
+        client = IGWNAlertClient(group='gracedb-test')
         topics = ['superevent', 'cbc_gstlal']
         client.listen(process_alert, topics)
 
@@ -220,21 +220,25 @@ class client(Stream):
         else:
             listen_topics = self.get_topics()
 
-        with self.open(self._construct_topic_url(listen_topics), "r") as s:
-            for payload, metadata in s.read(metadata=True,
-                                            batch_size=self.batch_size,
-                                            batch_timeout=self.batch_timeout):
-                try:
-                    payload = json.loads(payload)
-                except (JSONDecodeError, TypeError) as e:
-                    warnings.warn("Payload is not valid json: {}".format(e))
-
-                if not callback:
-                    print("New message from topic {topic}: {msg}"
-                          .format(topic=metadata.topic, msg=payload))
-                else:
-                    callback(topic=metadata.topic.split('.')[1],
-                             payload=payload)
+        try:
+            with self.open(self._construct_topic_url(listen_topics), "r") as s:
+                for payload, metadata in s.read(
+                        metadata=True,
+                        batch_size=self.batch_size,
+                        batch_timeout=self.batch_timeout):
+                    try:
+                        payload = json.loads(payload)
+                    except (JSONDecodeError, TypeError) as e:
+                        warnings.warn("Payload is not valid json: {}".format(
+                            e))
+                    if not callback:
+                        print("New message from topic {topic}: {msg}"
+                              .format(topic=metadata.topic, msg=payload))
+                    else:
+                        callback(topic=metadata.topic.split('.')[1],
+                                 payload=payload)
+        except (KeyboardInterrupt, SystemExit):
+            pass
 
     def connect(self, topics):
         """
@@ -313,7 +317,7 @@ class client(Stream):
 
     def publish(self, topic, msg=None):
         """
-        Send an LVAlert without pre-establishing a session.
+        Send an alert without pre-establishing a session.
 
         Parameters
         ----------
@@ -334,7 +338,7 @@ class client(Stream):
         Parameters
         ----------
         group : :obj:`str` (optional)
-            Group prefix (e.g., "lvalert", "lvalert-playground") to show
+            Group prefix (e.g., "gracedb", "gracedb-playground") to show
             topics for. If :obj:`None`, list topics for the current group.
 
         """
